# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.attributes_api import AttributesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestAttributesApi(unittest.TestCase):
    """AttributesApi unit test stubs"""

    def setUp(self):
        self.api = AttributesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_attribute(self):
        """Test case for add_attribute

        Add attribute  # noqa: E501
        """
        pass

    def test_add_attributes(self):
        """Test case for add_attributes

        Add attributes  # noqa: E501
        """
        pass

    def test_change_attribute(self):
        """Test case for change_attribute

        Change attribute  # noqa: E501
        """
        pass

    def test_change_attributes(self):
        """Test case for change_attributes

        Change attributes  # noqa: E501
        """
        pass

    def test_find_attributes(self):
        """Test case for find_attributes

        Find attributes  # noqa: E501
        """
        pass

    def test_get_attribute(self):
        """Test case for get_attribute

        Get attribute  # noqa: E501
        """
        pass

    def test_remove_attribute(self):
        """Test case for remove_attribute

        Remove attribute  # noqa: E501
        """
        pass

    def test_remove_attributes(self):
        """Test case for remove_attributes

        Remove attributes  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
