# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.models.add_asset_tags_request import AddAssetTagsRequest  # noqa: E501
from collibra_core.rest import ApiException


class TestAddAssetTagsRequest(unittest.TestCase):
    """AddAssetTagsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddAssetTagsRequest(self):
        """Test AddAssetTagsRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = collibra_core.models.add_asset_tags_request.AddAssetTagsRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
