# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "collibra-core_200"
VERSION = "2.0.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

with open("README.md", "r") as f:
    DESCRIPTION = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="Collibra Data Governance Center Core API",
    author_email="",
    url="",
    keywords=["Swagger", "Collibra Data Governance Center Core API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=DESCRIPTION,
    long_description_content_type="text/markdown"
)
